# -*- Mode: Perl; indent-tabs-mode: nil; -*-

package Bundle::Wombat;

require 5.6;

our $VERSION = '0.7.1';

1;
__END__

=pod

=head1 NAME

Bundle::Wombat - a bundle to install all Wombat related modules

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Wombat'>

=head1 CONTENTS

Digest

File::Spec

XML::Parser::PerlSAX

Bundle::LWP

Bundle::libservlet 0.9.3

=head1 DESCRIPTION

This bundle includes the Wombat distribution as well as C<libservlet>,
B<LWP> and other classes.

=head1 AUTHOR

Brian Moseley, bcm@maz.org

=cut
